@@ -2,25 +2,12 @@ from geopy.geocoders import Nominatim
 from geopy.distance import great_circle
 import requests
 
-total_distance = None
-
-def getDistance(scale='km'):
-	try:
-		if scale.lower()=="km":
-			return total_distance.km
-		if scale.lower()=="mile":
-			return total_distance.miles
-		return "Choose between (km / mile) only"
-	except:
-		print("Check the Arguments")
-
 def getCurrentLocation():
 	res = requests.get("https://ipinfo.io/")
 	data = res.json()
 	return data
 
 def getDirection(startingPoint, destinationPoint):
-	global total_distance
 
 	geolocator = Nominatim(user_agent='gmap')
 	if 'current' in startingPoint:
@@ -38,4 +25,14 @@ def getDirection(startingPoint, destinationPoint):
 	destinationlocationCoordinate = (destinationlocation.latitude, destinationlocation.longitude)
 	total_distance = great_circle(startinglocationCoordinate, destinationlocationCoordinate)
 	
-	return URL
\ No newline at end of file
+	result = {
+		"url": URL,
+		"total_distance(km)": total_distance.km,
+		"total_distance(miles)": total_distance.miles,
+		"Starting address": startingPoint,
+		"Starting Co-ordinates": startinglocationCoordinate,
+		"Destination Address": destinationPoint,
+		"Destination Co-ordinates": destinationlocationCoordinate
+	}
+
+	return result
